@@ -840,9 +840,6 @@ impl<W: Write> Write for HttpWriter<W> {
 
     #[inline]
     fn flush(&mut self) -> io::Result<()> {
-        #[cfg(unix)]
-        return Ok(());
-        #[cfg(not(unix))]
         return match *self {
             ThroughWriter(ref mut w) => w.flush(),
             ChunkedWriter(ref mut w) => w.flush(),
